@@ -1,5 +1,5 @@
 package Statocles::App::Blog;
-$Statocles::App::Blog::VERSION = '0.073';
+$Statocles::App::Blog::VERSION = '0.074';
 # ABSTRACT: A blog application
 
 use Statocles::Base 'Class';
@@ -451,7 +451,7 @@ sub tag_pages {
 # sub pages
 around pages => sub {
     my ( $orig, $self, %opt ) = @_;
-    $opt{date} ||= DateTime::Moonpig->now->ymd;
+    $opt{date} ||= DateTime::Moonpig->now( time_zone => 'local' )->ymd;
     my $root = $self->url_root;
     my $is_dated_path = qr{^$root/?(\d{4})/(\d{2})/(\d{2})/};
     my @parent_pages = $self->$orig( %opt );
@@ -613,7 +613,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.073
+version 0.074
 
 =head1 DESCRIPTION
 
