@@ -1,5 +1,5 @@
 package Statocles::App::Perldoc;
-$Statocles::App::Perldoc::VERSION = '0.073';
+$Statocles::App::Perldoc::VERSION = '0.074';
 # ABSTRACT: Render documentation for Perl modules
 
 use Statocles::Base 'Class';
@@ -253,6 +253,14 @@ sub _weave_module {
             ;
     }
 
+    # Check for a config and give a friendly error message if missing.
+    # The default exception thrown by a missing config is very difficult
+    # to understand out of context
+    if ( !$self->weave_config->parent->child( 'weaver.ini' )->is_file ) {
+        die sprintf q{Cannot find Pod::Weaver config in "%s". Missing "weaver.ini" file?},
+            $self->weave_config->parent;
+    }
+
     my $perl_utf8 = Encode::encode( 'utf-8', Path::Tiny->new( $path )->slurp, Encode::FB_CROAK );
     my $ppi_document = PPI::Document->new( \$perl_utf8 ) or die PPI::Document->errstr;
 
@@ -302,13 +310,20 @@ sub _weave_module {
 
     ### MUNGE THE POD HERE!
 
-    my $weaver = Pod::Weaver->new_from_config(
-        { root => $self->weave_config->parent->stringify },
-    );
-    my $weaved_doc = $weaver->weave_document({
-        pod_document => $pod_document,
-        ppi_document => $ppi_document,
-    });
+    my $weaved_doc;
+    eval {
+        my $weaver = Pod::Weaver->new_from_config(
+            { root => $self->weave_config->parent->stringify },
+        );
+        $weaved_doc = $weaver->weave_document({
+            pod_document => $pod_document,
+            ppi_document => $ppi_document,
+        });
+    };
+
+    if ( $@ ) {
+        die sprintf q{Error weaving POD for path "%s": %s}, $path, $@;
+    }
 
     ### END MUNGE THE POD
 
@@ -332,7 +347,7 @@ Statocles::App::Perldoc - Render documentation for Perl modules
 
 =head1 VERSION
 
-version 0.073
+version 0.074
 
 =head1 DESCRIPTION
 
