@@ -1,6 +1,6 @@
 package Statocles::Page;
-$Statocles::Page::VERSION = '0.073';
-# ABSTRACT: Base class for rendering objects
+$Statocles::Page::VERSION = '0.074';
+# ABSTRACT: Base role for rendering files
 
 use Statocles::Base 'Role';
 use Statocles::Template;
@@ -105,7 +105,7 @@ has date => (
     isa => DateTimeObj,
     coerce => DateTimeObj->coercion,
     lazy => 1,
-    default => sub { DateTime::Moonpig->now },
+    default => sub { DateTime::Moonpig->now( time_zone => 'local' ) },
 );
 
 #pod =attr data
@@ -412,11 +412,11 @@ __END__
 
 =head1 NAME
 
-Statocles::Page - Base class for rendering objects
+Statocles::Page - Base role for rendering files
 
 =head1 VERSION
 
-version 0.073
+version 0.074
 
 =head1 DESCRIPTION
 
