@@ -1,5 +1,5 @@
 package Statocles::Page::Document;
-$Statocles::Page::Document::VERSION = '0.073';
+$Statocles::Page::Document::VERSION = '0.074';
 # ABSTRACT: Render document objects into HTML
 
 use Statocles::Base 'Class';
@@ -53,7 +53,7 @@ has '+date' => (
     lazy => 1,
     default => sub {
         my ( $self ) = @_;
-        $self->document->date || DateTime::Moonpig->now;
+        $self->document->date || DateTime::Moonpig->now( time_zone => 'local' );
     },
 );
 
@@ -226,7 +226,7 @@ Statocles::Page::Document - Render document objects into HTML
 
 =head1 VERSION
 
-version 0.073
+version 0.074
 
 =head1 DESCRIPTION
 
